@@ -663,15 +663,6 @@ class TestHive(Validator):
                 "spark": "SELECT * FROM x.z TABLESAMPLE (10 PERCENT) AS y",
             },
         )
-        self.validate_all(
-            "SELECT SORT_ARRAY(x)",
-            write={
-                "duckdb": "SELECT ARRAY_SORT(x)",
-                "presto": "SELECT ARRAY_SORT(x)",
-                "hive": "SELECT SORT_ARRAY(x)",
-                "spark": "SELECT SORT_ARRAY(x)",
-            },
-        )
         self.validate_all(
             "SELECT SORT_ARRAY(x, FALSE)",
             read={
@@ -917,3 +908,25 @@ class TestHive(Validator):
                 "hive": "CAST(a AS BOOLEAN)",
             },
         )
+
+    def test_joins_without_on(self):
+        for join in ("FULL OUTER", "LEFT", "RIGHT", "LEFT OUTER", "RIGHT OUTER", "INNER"):
+            with self.subTest(f"Testing transpilation of {join} without ON"):
+                self.validate_all(
+                    f"SELECT * FROM t1 {join} JOIN t2 ON TRUE",
+                    read={
+                        "hive": f"SELECT * FROM t1 {join} JOIN t2",
+                        "spark2": f"SELECT * FROM t1 {join} JOIN t2",
+                        "spark": f"SELECT * FROM t1 {join} JOIN t2",
+                        "databricks": f"SELECT * FROM t1 {join} JOIN t2",
+                        "sqlite": f"SELECT * FROM t1 {join} JOIN t2",
+                    },
+                    write={
+                        "hive": f"SELECT * FROM t1 {join} JOIN t2 ON TRUE",
+                        "spark2": f"SELECT * FROM t1 {join} JOIN t2 ON TRUE",
+                        "spark": f"SELECT * FROM t1 {join} JOIN t2 ON TRUE",
+                        "databricks": f"SELECT * FROM t1 {join} JOIN t2 ON TRUE",
+                        "sqlite": f"SELECT * FROM t1 {join} JOIN t2 ON TRUE",
+                        "duckdb": f"SELECT * FROM t1 {join} JOIN t2 ON TRUE",
+                    },
+                )
