@@ -284,6 +284,7 @@ SELECT * FROM test FETCH FIRST ROWS ONLY
 SELECT * FROM test FETCH FIRST 1 ROWS ONLY
 SELECT * FROM test ORDER BY id DESC FETCH FIRST 10 ROWS WITH TIES
 SELECT * FROM test ORDER BY id DESC FETCH FIRST 10 PERCENT ROWS WITH TIES
+SELECT * FROM test ORDER BY always DESC
 SELECT * FROM test FETCH NEXT 1 ROWS ONLY
 SELECT (1 > 2) AS x FROM test
 SELECT NOT (1 > 2) FROM test
@@ -923,8 +924,17 @@ SELECT SEC(x)
 SELECT SECH(x)
 SELECT UTC_DATE
 SELECT UTC_TIME
+SELECT UTC_TIMESTAMP
 SELECT SIN(x)
 SELECT SINH(x)
 SELECT COSINE_DISTANCE(v1, v2)
 SELECT EUCLIDEAN_DISTANCE(v1, v2)
 FOO(values.c)
+case.*
+SELECT unknown
+SELECT test.Unknown FROM test
+SELECT lock
+SELECT a FROM test GROUP BY GROUPING SETS ((x + y, z))
+SELECT (LEAD(foo1, 1, 0)) OVER (PARTITION BY foo2 ORDER BY foo3) FROM t
+SELECT LAST_VALUE(CASE WHEN interval <> 'foo' THEN interval END) IGNORE NULLS FROM t
+WITH UNNEST AS (SELECT 1 AS UNNEST) SELECT UNNEST FROM UNNEST
