@@ -1559,6 +1559,50 @@ VARCHAR;
 AI_CLASSIFY('text', ['travel', 'cooking'], {'output_mode': 'multi'});
 VARCHAR;
 
+# dialect: snowflake
+ASCII('A');
+INT;
+
+# dialect: snowflake
+ASCII('');
+INT;
+
+# dialect: snowflake
+ASCII(NULL);
+INT;
+
+# dialect: snowflake
+BASE64_DECODE_BINARY('SGVsbG8=');
+BINARY;
+
+# dialect: snowflake
+BASE64_DECODE_STRING('SGVsbG8gV29ybGQ=');
+VARCHAR;
+
+# dialect: snowflake
+BASE64_DECODE_STRING('SGVsbG8gV29ybGQ=', 'ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/');
+VARCHAR;
+
+# dialect: snowflake
+BASE64_ENCODE('Hello World', 76);
+VARCHAR;
+
+# dialect: snowflake
+BASE64_ENCODE('Hello World', 76, 'ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/');
+VARCHAR;
+
+# dialect: snowflake
+BIT_LENGTH('abc');
+INT;
+
+# dialect: snowflake
+BIT_LENGTH(tbl.str_col);
+INT;
+
+# dialect: snowflake
+BIT_LENGTH(tbl.bin_col);
+INT;
+
 # dialect: snowflake
 CHARINDEX('world', 'hello world');
 INT;
@@ -1567,6 +1611,62 @@ INT;
 CHARINDEX('world', 'hello world', 1);
 INT;
 
+# dialect: snowflake
+CHAR(65);
+VARCHAR;
+
+# dialect: snowflake
+CHR(8364);
+VARCHAR;
+
+# dialect: snowflake
+COLLATE('hello', 'utf8');
+VARCHAR;
+
+# dialect: snowflake
+COMPRESS('Hello World', 'SNAPPY');
+BINARY;
+
+# dialect: snowflake
+COMPRESS('Hello World', 'zlib(1)');
+BINARY;
+
+# dialect: snowflake
+DECOMPRESS_BINARY('compressed_data', 'SNAPPY');
+BINARY;
+
+# dialect: snowflake
+DECOMPRESS_STRING('compressed_data', 'ZSTD');
+VARCHAR;
+
+# dialect: snowflake
+LPAD('Hello', 10, '*');
+VARCHAR;
+
+# dialect: snowflake
+LPAD(tbl.str_col, 10);
+VARCHAR;
+
+# dialect: snowflake
+LPAD(tbl.bin_col, 10, 0x20);
+BINARY;
+
+# dialect: snowflake
+RPAD('Hello', 10, '*');
+VARCHAR;
+
+# dialect: snowflake
+RPAD(tbl.str_col, 10);
+VARCHAR;
+
+# dialect: snowflake
+RPAD(tbl.bin_col, 10, 0x20);
+BINARY;
+
+# dialect: snowflake
+COLLATION('hello');
+VARCHAR;
+
 # dialect: snowflake
 CONCAT('Hello', 'World!');
 VARCHAR;
@@ -1603,6 +1703,18 @@ BOOLEAN;
 CONTAINS(tbl.bin_col, NULL);
 BOOLEAN;
 
+# dialect: snowflake
+EDITDISTANCE('hello', 'world');
+INT;
+
+# dialect: snowflake
+EDITDISTANCE(tbl.str_col, 'test');
+INT;
+
+# dialect: snowflake
+EDITDISTANCE('hello', 'world', 3);
+INT;
+
 # dialect: snowflake
 ENDSWITH('hello world', 'world');
 BOOLEAN;
@@ -1619,6 +1731,50 @@ BOOLEAN;
 ENDSWITH(tbl.bin_col, NULL);
 BOOLEAN;
 
+# dialect: snowflake
+HEX_DECODE_BINARY('48656C6C6F');
+BINARY;
+
+# dialect: snowflake
+HEX_DECODE_STRING('48656C6C6F');
+VARCHAR;
+
+# dialect: snowflake
+HEX_ENCODE('Hello World');
+VARCHAR;
+
+# dialect: snowflake
+HEX_ENCODE('Hello World', 'upper');
+VARCHAR;
+
+# dialect: snowflake
+HEX_ENCODE('Hello World', 'lower');
+VARCHAR;
+
+# dialect: snowflake
+INITCAP('hello world');
+VARCHAR;
+
+# dialect: snowflake
+INITCAP('hello world', ' ');
+VARCHAR;
+
+# dialect: snowflake
+INITCAP(tbl.str_col);
+VARCHAR;
+
+# dialect: snowflake
+JAROWINKLER_SIMILARITY('hello', 'world');
+INT;
+
+# dialect: snowflake
+INSERT('abc', 1, 2, 'Z');
+VARCHAR;
+
+# dialect: snowflake
+INSERT(tbl.bin_col, 1, 2, tbl.bin_col);
+BINARY;
+
 # dialect: snowflake
 LEAST(x::DECIMAL(18, 2));
 DECIMAL(18, 2);
@@ -1655,6 +1811,34 @@ INT;
 LENGTH(tbl.bin_col);
 INT;
 
+# dialect: snowflake
+OCTET_LENGTH(tbl.str_col);
+INT;
+
+# dialect: snowflake
+OCTET_LENGTH(tbl.bin_col);
+INT;
+
+# dialect: snowflake
+PARSE_URL('https://example.com/path');
+OBJECT;
+
+# dialect: snowflake
+PARSE_URL(tbl.str_col, 0);
+OBJECT;
+
+# dialect: snowflake
+POSITION('abc' IN 'abcdef');
+INT;
+
+# dialect: snowflake
+POSITION('abc', 'abcdef');
+INT;
+
+# dialect: snowflake
+POSITION('abc', 'abcdef', 1);
+INT;
+
 # dialect: snowflake
 LOWER(tbl.str_col);
 VARCHAR;
@@ -1671,6 +1855,18 @@ VARCHAR;
 LTRIM(NULL);
 VARCHAR;
 
+# dialect: snowflake
+'foo' REGEXP 'bar';
+BOOLEAN;
+
+# dialect: snowflake
+'foo' NOT REGEXP 'bar';
+BOOLEAN;
+
+# dialect: snowflake
+'text123' REGEXP '^[a-z]+[0-9]+$';
+BOOLEAN;
+
 # dialect: snowflake
 REGEXP_LIKE('foo', 'bar');
 BOOLEAN;
@@ -1687,6 +1883,18 @@ BOOLEAN;
 REGEXP_LIKE('foo', NULL, 'baz');
 BOOLEAN;
 
+# dialect: snowflake
+REGEXP_COUNT('hello world', 'l');
+DECIMAL(38, 0);
+
+# dialect: snowflake
+REGEXP_COUNT('hello world', 'l', 1);
+DECIMAL(38, 0);
+
+# dialect: snowflake
+REGEXP_COUNT('hello world', 'l', 1, 'i');
+DECIMAL(38, 0);
+
 # dialect: snowflake
 REGEXP_REPLACE('hello world', 'world', 'universe');
 VARCHAR;
@@ -1795,6 +2003,10 @@ VARCHAR;
 RTRIM(NULL);
 VARCHAR;
 
+# dialect: snowflake
+RTRIMMED_LENGTH(' ABCD ');
+INT;
+
 # dialect: snowflake
 SHA1('foo');
 VARCHAR;
@@ -1867,6 +2079,10 @@ VARCHAR;
 SHA2_HEX('foo', null);
 VARCHAR;
 
+# dialect: snowflake
+SOUNDEX(tbl.str_col);
+VARCHAR;
+
 # dialect: snowflake
 SPACE(5);
 VARCHAR;
@@ -1891,6 +2107,10 @@ ARRAY;
 SPLIT(NULL, ',');
 ARRAY;
 
+# dialect: snowflake
+SPLIT_PART('11.22.33', '.', 1);
+VARCHAR;
+
 # dialect: snowflake
 STARTSWITH('hello world', 'hello');
 BOOLEAN;
@@ -1943,6 +2163,30 @@ VARCHAR;
 TRIM(NULL);
 VARCHAR;
 
+# dialect: snowflake
+TRY_BASE64_DECODE_BINARY('SGVsbG8=');
+BINARY;
+
+# dialect: snowflake
+TRY_BASE64_DECODE_BINARY('SGVsbG8=', 'ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/');
+BINARY;
+
+# dialect: snowflake
+TRY_BASE64_DECODE_STRING('SGVsbG8gV29ybGQ=');
+VARCHAR;
+
+# dialect: snowflake
+TRY_BASE64_DECODE_STRING('SGVsbG8gV29ybGQ=', 'ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/');
+VARCHAR;
+
+# dialect: snowflake
+TRY_HEX_DECODE_BINARY('48656C6C6F');
+BINARY;
+
+# dialect: snowflake
+TRY_HEX_DECODE_STRING('48656C6C6F');
+VARCHAR;
+
 # dialect: snowflake
 UPPER('Hello, world!');
 VARCHAR;
@@ -2019,6 +2263,18 @@ BOOLEAN;
 tbl.str_col ILIKE ANY ('h%', '%x');
 BOOLEAN;
 
+# dialect: snowflake
+LIKE(tbl.str_col, 'pattern');
+BOOLEAN;
+
+# dialect: snowflake
+ILIKE(tbl.str_col, 'pattern');
+BOOLEAN;
+
+# dialect: snowflake
+PARSE_IP('192.168.1.1', 'INET');
+OBJECT;
+
 --------------------------------------
 -- T-SQL
 --------------------------------------
