@@ -329,7 +329,12 @@ FROM
   t1;
 SELECT x.a AS a, x.b AS b, ROW_NUMBER() OVER (PARTITION BY x.a ORDER BY x.a) AS row_num FROM x AS x ORDER BY x.a, x.b, row_num;
 
-# title: Don't merge window functions, inner table is aliased in outer query
+# title: Keep ORDER BY
+# execute: false
+WITH t AS (SELECT t1.x AS x, t1.y AS y, t2.a AS a, t2.b AS b FROM t1 AS t1(x, y) CROSS JOIN t2 AS t2(a, b) ORDER BY t2.a) SELECT t.x AS x, t.y AS y, t.a AS a, t.b AS b FROM t AS t;
+SELECT t1.x AS x, t1.y AS y, t2.a AS a, t2.b AS b FROM t1 AS t1(x, y) CROSS JOIN t2 AS t2(a, b) ORDER BY t2.a;
+
+# title: Do not merge window functions, inner table is aliased in outer query
 with t1 as (
   SELECT
     ROW_NUMBER() OVER (PARTITION BY x.a ORDER BY x.a) as row_num
@@ -498,4 +503,11 @@ SELECT
 FROM i
 LEFT JOIN j AS conflict
   ON i.a = conflict.a;
-WITH j AS (SELECT 1 AS a) SELECT conflict_2.a AS a, conflict.a AS a FROM (SELECT 1 AS a) AS conflict_2 LEFT JOIN j AS conflict ON conflict_2.a = conflict.a;
\ No newline at end of file
+WITH j AS (SELECT 1 AS a) SELECT conflict_2.a AS a, conflict.a AS a FROM (SELECT 1 AS a) AS conflict_2 LEFT JOIN j AS conflict ON conflict_2.a = conflict.a;
+
+# title: column name is not lost
+with cte as (
+    select x.a * x.b as mult from x
+)
+select cte.mult from cte;
+SELECT x.a * x.b AS mult FROM x AS x;
